@@ -3,12 +3,13 @@ package Bit::Manip;
 use warnings;
 use strict;
 
-our $VERSION = '1.03';
+our $VERSION = '1.04';
 
 require XSLoader;
 XSLoader::load('Bit::Manip', $VERSION);
 
-use Exporter qw(import);
+use Exporter;
+our @ISA = qw(Exporter);
 
 our @EXPORT_OK = qw(
     bit_get
@@ -17,6 +18,7 @@ our @EXPORT_OK = qw(
     bit_bin
     bit_count
     bit_mask
+    bit_tog
     bit_toggle
     bit_on
     bit_off
@@ -59,9 +61,14 @@ sub bit_set {
     my ($data, $lsb, $nbits, $value) = @_;
     return _bit_set($data, $lsb, $nbits, $value);
 }
-sub bit_toggle {
+
+# alias bit_toggle() into play
+
+*bit_toggle = \&bit_tog;
+
+sub bit_tog {
     my ($data, $bit) = @_;
-    return _bit_toggle($data, $bit);
+    return _bit_tog($data, $bit);
 }
 sub bit_on {
     my ($data, $bit) = @_;
@@ -87,9 +94,13 @@ Bit::Manip - Functions to simplify bit string manipulation
     my $b;    # bit string
     $b = 128; # 10000000
 
-    $b = bit_toggle($b, 4); # 10010000
-    $b = bit_toggle($b, 4); # 10000000
-    
+    # toggle a bit off and on
+
+    $b = bit_tog($b, 4); # 10010000
+    $b = bit_tog($b, 4); # 10000000
+
+    # turn a bit off, then back on
+
     $b = bit_off($b, 7);    # 0 
     $b = bit_on($b, 7);     # 10000000 
 
@@ -132,6 +143,9 @@ communication software.
 
 Currently, up to 32-bit integers are supported.
 
+Note that if your machine isn't capable of compiling C code, there's a pure Perl
+version as well, aptly named L<Bit::Manip::PP>.
+
 =head1 EXPORT_OK
 
 Use the C<:all> tag (eg: C<use Bit::Manip qw(:all);>) to import the following
@@ -140,7 +154,7 @@ functions into your namespace, or pick and choose individually:
     bit_get
     bit_set
     bit_clr
-    bit_toggle
+    bit_tog
     bit_on
     bit_off
     bit_bin
@@ -149,7 +163,7 @@ functions into your namespace, or pick and choose individually:
 
 =head1 FUNCTIONS
 
-=head2 bit_get
+=head2 bit_get($data, $msb, $lsb)
 
 Retrieves the value of specified bits within a bit string.
 
@@ -172,11 +186,11 @@ Optional: Integer, the Least Significant Bit (rightmost) of the group of bits to
 collect the value for (starting at 0 from the right). A value of C<0> means
 return the value from C<$msb> through to the very end of the bit string. A
 value of C<1> will capture from C<$msb> through to bit C<1> (second from
-right). This value must be lower than C<$msb>.
+right). If C<$msb> is equal to C<$lsb>, we'll return just that bit.
 
 Return: Integer, the modified C<$data> param.
 
-=head2 bit_set
+=head2 bit_set($data, $lsb, $nbits, $value)
 
 Allows you to set a value for specific bits in your bit string.
 
@@ -224,7 +238,7 @@ Code:
     my $x = bit_set($data, 4, 3, 0b111); # (0x07, or 7)
     printf("%b\n", $x); # prints 11110000
 
-=head2 bit_clr
+=head2 bit_clr($data, $lsb, $nbits)
 
 Clear (unset to 0) specific bits in the bit string.
 
@@ -247,7 +261,13 @@ the C<$lsb> bit, and clearing the number of bits to the left.
 
 Returns the modified bit string.
 
-=head2 bit_toggle
+=head2 bit_toggle($data, $bit)
+
+See L</bit_tog>.
+
+=head2 bit_tog($data, $bit)
+
+AKA: C<bit_toggle()>.
 
 Toggles a single bit. If it's C<0> it'll toggle to C<1> and vice-versa.
 
@@ -264,7 +284,7 @@ starting from C<0>.
 
 Return: Integer, the modified C<$data> param.
 
-=head2 bit_on
+=head2 bit_on($data, $bit)
 
 Sets a single bit (sets to C<1>), regardless of its current state. This is just
 a short form of setting a single bit with L<bit_set>.
@@ -282,7 +302,7 @@ starting from C<0>.
 
 Return: Integer, the modified C<$data> param.
 
-=head2 bit_off
+=head2 bit_off($data, $bit)
 
 Unsets a single bit (sets to C<0>), regardless of its current state. This is
 just a short form of clearing a single bit with L<bit_set>.
@@ -300,7 +320,7 @@ starting from C<0>.
 
 Return: Integer, the modified C<$data> param.
 
-=head2 bit_bin
+=head2 bit_bin($data)
 
 Returns the binary representation of a number as a string of ones and zeroes.
 
@@ -310,7 +330,7 @@ Parameters:
 
 Mandatory: Integer, the number you want to convert.
 
-=head2 bit_count
+=head2 bit_count($num, $set)
 
 Returns either the total count of bits in a number, or just the number of set
 bits (if the C<$set>, parameter is sent in and is true).
@@ -333,7 +353,7 @@ all four of the total).
 Return: Integer, the number of bits that make up the number if C<$set> is C<0>,
 and the number of set bits (1's) if C<$set> is true.
 
-=head2 bit_mask
+=head2 bit_mask($nbits, $lsb)
 
 Generates a bit mask for the specific bits you specify.
 
